package Bencher::Scenarios::Perinci;

our $DATE = '2017-01-25'; # DATE
our $VERSION = '0.05'; # VERSION

use 5.010001;
use strict;
use warnings;

1;
# ABSTRACT: A collection of bencher scenarios to benchmark Perinci::*

__END__

=pod

=encoding UTF-8

=head1 NAME

Bencher::Scenarios::Perinci - A collection of bencher scenarios to benchmark Perinci::*

=head1 VERSION

This document describes version 0.05 of Bencher::Scenarios::Perinci (from Perl distribution Bencher-Scenarios-Perinci), released on 2017-01-25.

=head1 DESCRIPTION

This distribution contains the following L<Bencher> scenario modules:

=over

=item * L<Bencher::Scenario::PerinciSubNormalize>

=item * L<Bencher::Scenario::PerinciEnvRes>

=item * L<Bencher::Scenario::PerinciExamples::Startup>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Bencher-Scenarios-Perinci>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Bencher-Scenario-Perinci>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Bencher-Scenarios-Perinci>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

For Perinci::CmdLine-related benchmarks, please see the
L<Bencher::Scenarios::PerinciCmdLine> distribution.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2017 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
